
import 'dart:async';
import 'dart:io';
import 'package:dart_json_mapper/dart_json_mapper.dart';
import 'package:get/get.dart';
import 'package:naiyouwl/app/common/constants.dart';
import 'package:naiyouwl/app/const/const.dart';
import 'package:naiyouwl/app/controller/GlobalController.dart';
import 'package:naiyouwl/app/controller/controllers.dart';
import 'package:naiyouwl/app/utils/shell.dart';
import 'package:naiyouwl/app/utils/utils.dart';
import 'package:url_launcher/url_launcher.dart';
import '../../../clash/service/clash_service.dart';
import '../../../common/LogHelper.dart';
import '../../../common/SharedPreferencesUtil.dart';
import '../../../component/connection_status.dart';
import '../../../data/model/LocalUser.dart';
import '../../../data/model/NodeMode.dart';
import '../../../data/model/SysConfig.dart';
import '../../../data/model/UserMode.dart';
import '../../../network/api_service.dart';
import '../../../routes/app_pages.dart';
import 'package:path/path.dart' as path;


import '../../../service/connection_service.dart';
import '../../../service/local_storage_service.dart';
import '../../../service/network_service.dart';
import '../../../service/user_service.dart';

enum ImageType {
  CUSTOMER,
  PROMOTION,
  TUTORIAL,
  RENEWAL,
}

class HomeController extends GetxController {
  //TODO: Implement HomeController

  var isLoading = false.obs;
  var sysConfig = SysConfig().obs;
  var localUsers = LocalUser().obs;
  var userMode = User().obs;
  var UsersysConfig = SysConfig().obs;
  var serviceStuatus = false.obs;
  var coreStuatus = false.obs;
  var connectStatus = Rx<ConnectionStatus>(ConnectionStatus.disconnected);
  var nodeModes = <NodeMode>[];
  var isConnect = false.obs;
  var errAdminMsg = false.obs;
  var errAdmin = ''.obs;
  var isInit = false.obs;
  var isServiceInstall = false.obs;

  bool get isRunning =>
      connectStatus.value == ConnectionStatus.stopped &&
          controllers.global.allowStatusUpdate;
  late final GlobalController globalController = controllers.global;
  StreamSubscription<RunningState>? _statusSubscription;
  final Map<ImageType, String> imageMap = {
    ImageType.CUSTOMER: "assets/images/main/customer.png",
    ImageType.PROMOTION: "assets/images/main/promotion.png",
    ImageType.TUTORIAL: "assets/images/main/tutorial.png",
    ImageType.RENEWAL: "assets/images/main/renewal.png",
  };

  final NetworkService networkService = NetworkService(controllers.global);
  final LocalStorageService localStorageService = LocalStorageService();
  final UserService userService = UserService(controllers.global);


  late final ConnectionService connectionService;

  void onImageTap(ImageType type) async {
    if (type == ImageType.CUSTOMER) {
      await launchUrl(Uri.parse(UsersysConfig.value.userTicket ?? ""));
    } else if (type == ImageType.PROMOTION) {
      await launchUrl(Uri.parse(UsersysConfig.value.affUrl ?? ""));
    } else if (type == ImageType.TUTORIAL) {
      await launchUrl(Uri.parse(UsersysConfig.value.userDownload ?? ""));
    } else if (type == ImageType.RENEWAL) {
      await launchUrl(Uri.parse(UsersysConfig.value.userBuy ?? ""));
    }
    LogHelper().d("${imageMap[type]} tapped as ${type
        .toString()
        .split('.')
        .last}");
  }

  void updateStatus(ConnectionStatus newStatus) {
    connectStatus.value = newStatus;
  }

  void _handleStateChange([dynamic _]) async {
    final coreStatus = controllers.service.coreStatus.value;
    final isVisible = controllers.window.isVisible.value;
    if (coreStatus == RunningState.running && isVisible &&
        controllers.global.allowStatusUpdate) {
      // 核心运行中且窗口可见时的逻辑
      if (connectStatus.value == ConnectionStatus.connecting) {
        controllers.global.updateMsg("连接完成...");
      }
    }
  }

  Future<void> handleButtonClick() async {
    if (userMode.value.enable != 1) {
      controllers.global.handleApiError("账号禁用,请刷新账号状态或重启软件");
      return;
    }

    if (connectStatus.value == ConnectionStatus.connecting) {
      return;
    }

    if (connectStatus.value == ConnectionStatus.stopped) {
      await connectionService.stopConnection();
    } else {
      await connectionService.startConnection();
    }
  }

  @override
  void onInit() {
    super.onInit();
    connectionService = ConnectionService(controllers.global, updateStatus);
    _statusSubscription =
        controllers.service.coreStatus.stream.listen(_handleStateChange);
  }

// 其他方法保持不变...
}